@@ -17,9 +17,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $LastChangedBy: bastian $
- * $LastChangedDate: 2007-05-13 21:11:02 +0000 (So, 13 Mai 2007) $
- * $LastChangedRevision: 1450 $
+ * $LastChangedBy$
+ * $LastChangedDate$
+ * $LastChangedRevision$
  */
 
 #include <config.h>
@@ -32,11 +32,12 @@
 #include <unistd.h>
 
 #include "check.h"
+#include "download.h"
 #include "execute.h"
 #include "frontend.h"
-#include "download.h"
-#include "packages.h"
-#include "prepare.h"
+#include "gpg.h"
+#include "package.h"
+#include "target.h"
 
 int decompress_file (const char *file, const char *extension)
 {
@@ -56,28 +57,45 @@ static int download_file (const char *source, const char *target, const char *me
 static di_release *download_release (void)
 {
   char source[256];
-  char target[4096], target1[4096];
+  char target[4096], sig_target[4096];
+  const char *message = "InRelease";
   di_release *ret;
 
-  build_indices_root ("Release", source, sizeof (source), target, sizeof (target));
+  build_indices_root ("InRelease", source, sizeof (source), target, sizeof (target));
 
-  if (download_file (source, target, "Release"))
-    log_message (LOG_MESSAGE_ERROR_DOWNLOAD_RETRIEVE, "Release");
-
-  build_indices_root ("Release.gpg", source, sizeof (source), target1, sizeof (target1));
-
-  if (download_file (source, target1, "Release.gpg"))
+  if (!download_file (source, target, "InRelease"))
   {
-    if (authentication)
-      log_message (LOG_MESSAGE_ERROR_DOWNLOAD_RETRIEVE, "Release.gpg");
+    if (gpg_check_release (target, NULL, "InRelease"))
+      log_message (authentication ? LOG_MESSAGE_ERROR_DOWNLOAD_VALIDATE : LOG_MESSAGE_WARNING_DOWNLOAD_VALIDATE, "InRelease");
   }
-  else if (check_release (target, target1))
-    log_message (authentication ? LOG_MESSAGE_ERROR_DOWNLOAD_VALIDATE : LOG_MESSAGE_WARNING_DOWNLOAD_VALIDATE, "Release");
+  else
+  {
+    log_message (LOG_MESSAGE_WARNING_DOWNLOAD_RETRIEVE, "InRelease");
 
-  log_message (LOG_MESSAGE_INFO_DOWNLOAD_PARSE, "Release");
+    message = "Release";
+
+    build_indices_root ("Release", source, sizeof (source), target, sizeof (target));
+    if (download_file (source, target, "Release"))
+      log_message (LOG_MESSAGE_ERROR_DOWNLOAD_RETRIEVE, "Release");
+
+    build_indices_root ("Release.gpg", source, sizeof (source), sig_target, sizeof (sig_target));
+
+    if (download_file (source, sig_target, "Release.gpg"))
+    {
+      if (authentication)
+        log_message (LOG_MESSAGE_ERROR_DOWNLOAD_RETRIEVE, "Release.gpg");
+    }
+    else if (gpg_check_release (target, sig_target, "Release"))
+      log_message (authentication ? LOG_MESSAGE_ERROR_DOWNLOAD_VALIDATE : LOG_MESSAGE_WARNING_DOWNLOAD_VALIDATE, "Release");
+  }
+
+  log_message (LOG_MESSAGE_INFO_DOWNLOAD_PARSE, message);
 
   if (!(ret = di_release_read_file (target)))
-    log_message (LOG_MESSAGE_ERROR_DOWNLOAD_PARSE, "Release");
+    log_message (LOG_MESSAGE_ERROR_DOWNLOAD_PARSE, message);
+
+  if (!suite && suite_use (ret->codename))
+    return NULL;
 
   return ret;
 }
@@ -188,29 +206,26 @@ static int download_debs (di_slist *install)
 
 int download (di_packages **packages, di_packages_allocator **allocator, di_slist **install)
 {
-  int ret;
-
   *allocator = di_packages_allocator_alloc ();
   if (!*allocator)
     return 1;
 
   *packages = download_indices (*allocator);
-  if (!packages)
+  if (!*packages)
     return 1;
 
   (*install) = suite_packages_list (*packages, *allocator);
   if (!*install)
-    log_text (DI_LOG_LEVEL_ERROR, "Couldn't not build installation list!");
+    log_text (DI_LOG_LEVEL_ERROR, "Couldn't build installation list");
 
-  ret = download_debs (*install);
-  if (ret)
-    return 1;
-
-  return 0;
+  return download_debs (*install);
 }
 
 int download_init (void)
 {
-  return prepare_download ();
+  target_create_dir ("/var");
+  target_create_dir ("/var/cache");
+  target_create_dir ("/var/cache/bootstrap");
+  return 0;
 }
 
